#![windows_subsystem = "windows"]
use std::env;
use reqwest;
use regex::Regex;
extern crate toml;
use std::fs;
use toml::Value;
use native_dialog::MessageType;
use native_dialog::MessageDialog;
use std::error::Error;

fn show_error(error_message: &str) {
    let result = MessageDialog::new()
        .set_type(MessageType::Error)
        .set_title("Ошибка")
        .set_text(error_message)
        .show_alert();
    if let Err(err) = result {
        eprintln!("Ошибка при отображении диалогового окна: {:?}", err);
    }
}

#[tokio::main]
async fn main() ->  Result<(), Box<dyn Error>> {
    if let Ok(current_exe) = env::current_exe() {
        if let Some(parent_dir) = current_exe.parent() {
            let path = format!("{}\\config.toml", parent_dir.to_string_lossy());
            let config_contents = fs::read_to_string(path)?;
            let config: Value = toml::from_str(&config_contents)?;
            let url2 = config["url"].to_string();
            let args: Vec<String> = env::args().collect();
            if args.len() > 1 {
                let re = Regex::new(r"\D+").unwrap();
                let phone_number = re.replace_all(&args[1], "");
                let url = format!("{}{}",url2.trim_matches('\"'), phone_number);
                let response = reqwest::get(&url).await?;
                let response_text = response.text().await?;
                // println!("Ответ сервера: {}", response_text);
            } else {
                show_error("Нет номера телефона для обработки!");
            }

        }
    }   
    Ok(())
}
